/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: jobcreatedatedtransfer_be.h 947 2006-02-21 17:04:54Z aquamaniac $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQBANKING_JOBCREATEDATEDTRANSFER_BE_H
#define AQBANKING_JOBCREATEDATEDTRANSFER_BE_H


#include <aqbanking/jobcreatedatedtransfer.h>

/** @addtogroup G_AB_JOBS_DATED_TRANSFER_MK
 *
 */
/*@{*/

/** @name Backend Functions
 *
 * Functions in this group are only to be called by banking backends.
 */
/*@{*/

/**
 * This function lets the backend specify the limits for some of the fields
 * of a @ref AB_TRANSACTION.
 */
AQBANKING_API
void AB_JobCreateDatedTransfer_SetFieldLimits(AB_JOB *j,
                                              AB_TRANSACTION_LIMITS *limits);

/*@}*/ 


/*@}*/ /* addtogroup */


#endif

